mafw.db.trigger
===============

.. automodule:: mafw.db.trigger

   
   .. rubric:: Functions

   .. autosummary::
   
      and_
      or_
   
   .. rubric:: Classes

   .. autosummary::
   
      Trigger
      TriggerAction
      TriggerWhen
   